<?php
/**
 * @file
 * Contains \Drupal\scheduled_updates\Tests\AddFieldScheduledUpdateTypeTest.
 */


namespace Drupal\scheduled_updates\Tests;
use Drupal\scheduled_updates\Plugin\UpdateRunnerInterface;

/**
 * Test adding an Embedded Scheduled Update Type via Manage Field page.
 *
 * @group scheduled_updates
 */
class AddFieldScheduledUpdateTypeTest extends EmbeddedScheduledUpdateTypeTestBase {

  /**
   * Permissions to grant admin user.
   *
   * @var array
   */
  protected $permissions = [
    'access administration pages',
    'administer content types',
    'administer nodes',
    'administer scheduled update types',
    'administer scheduled_update fields',
    'administer scheduled_update form display',
    'administer node fields',
    'administer content types',
    'administer node form display',
  ];

  protected function setUp() {
    parent::setUp();
    $this->drupalLogin($this->adminUser);
  }


  /**
   * Test to check from manage fields on Node.
   */
  public function testAddUpdateField () {
    $bundle = 'page';
    $clone_field = 'title';
    $clone_field_label = 'Title';
    $this->drupalGet("admin/structure/types/manage/$bundle/fields");
    $this->assertLink('Add Update field');
    $add_url = "admin/structure/types/manage/$bundle/fields/add-scheduled-update";
    $this->assertLinkByHref($add_url);
    $this->clickLink('Add Update field');
    $this->assertUrl("admin/structure/types/manage/$bundle/fields/add-scheduled-update");
    $this->assertText('Update Field');
    $this->checkRunnersAvailable(['default_embedded', 'latest_revision']);
    $this->checkNodeProperties();

    $type_id = 'foo';
    $label = 'Foo Type';
    $clone_fields = [
      'base_fields[title]' => [
        'input_value' => 'title',
        'label' => t('Title'),
      ]
    ];

    $this->checkExpectedOptions(
      'edit-update-runner-update-user',
      [
        UpdateRunnerInterface::USER_UPDATE_RUNNER,
        UpdateRunnerInterface::USER_UPDATE_OWNER,
        UpdateRunnerInterface::USER_OWNER,
        UpdateRunnerInterface::USER_REVISION_OWNER,
      ]
    );
    $edit = [
      'clone_field' => $clone_field,
      'update_runner[id]' => 'default_embedded',
      'update_runner[after_run]' => UpdateRunnerInterface::AFTER_DELETE,
      'update_runner[invalid_update_behavior]' => UpdateRunnerInterface::INVALID_DELETE,
      'update_runner[update_user]' => UpdateRunnerInterface::USER_UPDATE_RUNNER,
      'update_runner[create_revisions]' => UpdateRunnerInterface::REVISIONS_BUNDLE_DEFAULT,
      "reference_settings[bundles][$bundle]" => $bundle,
    ];


    $reference_field_label = 'Reference Label';
    $reference_field_name = 'update_reference';
    $this->checkNewFieldRequired($edit, $add_url, $reference_field_label, $reference_field_name);



    // Save a second time to redirect to clone page.
    $this->drupalPostForm(NULL,
      $edit,
      t('Save')
    );
    $this->assertUrl("admin/structure/types/manage/$bundle/form-display");

    $type_id = 'node__' . $clone_field;
    $type_label = 'Content - ' . $clone_field_label;
    $this->assertText("Created the $type_label Scheduled Update Type.");



    $this->drupalGet('admin/config/workflow/scheduled-update-type/list');
    $this->assertText($type_id);
    $this->assertText($type_label);

    $this->confirmNoAddForm($label, $type_id);
    // @todo - test, inline entity form on target, adding updates, running updates.
    $this->checkReferenceCreated('node', 'page', $reference_field_label, $reference_field_name);
    $this->checkReferenceOnEntityType('node', 'page', $reference_field_label, $reference_field_name);


  }


}
