<?php
/**
 * @file
 * Contains \Drupal\scheduled_updates\Tests\EmbeddedScheduledUpdateTypeTestBase.
 */


namespace Drupal\scheduled_updates\Tests;


class EmbeddedScheduledUpdateTypeTestBase extends ScheduledUpdatesTestBase{
  /**
   * Make sure Referenced types do not have a direct add form.
   *
   * @param $label
   * @param $type_id
   *
   */
  protected function confirmNoAddForm($label, $type_id) {
    $logged_id_user = $this->loggedInUser;
    $add_user = $this->createUser(
      ["create $type_id scheduled updates"]
    );
    $this->drupalLogin($add_user);

    $this->drupalGet('admin/content/scheduled-update/add');
    $this->assertNoText($label, 'Refereneced type label does not appear on update add page.');
    $this->assertNoText('Update Date/time', 'Update time field is not available on add page.');
    $this->checkAccessDenied('admin/content/scheduled-update/add/' . $type_id);

    $this->drupalLogin($logged_id_user);

  }
  /**
   * Make sure that reference field was created and put on target entity type.
   *
   * @param $entity_type
   * @param $bundle
   * @param $reference_field_label
   * @param $reference_field_name
   */
  protected function checkReferenceCreated($entity_type, $bundle, $reference_field_label, $reference_field_name) {
    $permissions = [
      'administer node fields',
      'administer content types',
    ];
    $fieldUser = $this->drupalCreateUser($permissions);
    $this->drupalLogin($fieldUser);
    $this->drupalGet("admin/structure/types/manage/$bundle/fields");
    $this->assertText($reference_field_label);
    $this->assertText($reference_field_name);
  }


  /**
   * Make sure that reference field was created and put on target entity type.
   *
   * @param $entity_type
   * @param $bundle
   * @param $reference_field_label
   * @param $reference_field_name
   */
  protected function checkReferenceOnEntityType($entity_type, $bundle, $reference_field_label, $reference_field_name) {
    $permissions = [
      "create $bundle content",

    ];
    $user = $this->drupalCreateUser($permissions);
    $this->drupalLogin($user);
    $this->drupalGet("node/add/$bundle");
    $this->assertText($reference_field_label);
    // @todo Check html for field

    // $field_id = 'edit-' . str_replace('_', '-', $reference_field_name);
    //$this->assertFieldbyId($field_id);
  }

  /**
   * @param $edit
   * @param $add_url
   * @param $reference_field_label
   * @param $reference_field_name
   *
   * @return array
   * @throws \Exception
   */
  protected function checkNewFieldRequired(array &$edit, $add_url, $reference_field_label, $reference_field_name) {
    // Save first without new field information.
    // This is only enforce by javascript states
    // @see \Drupal\scheduled_updates\Form\ScheduledUpdateTypeBaseForm::validateForm
    $this->drupalPostForm(NULL,
      $edit,
      t('Save')
    );
    $this->assertText('Please provide a name for the new field.');
    $this->assertText('Please provide a label for the new field.');
    $this->assertUrl($add_url);

    $edit += [
      'reference_settings[new_field][label]' => $reference_field_label,
      'reference_settings[new_field][field_name]' => $reference_field_name,
    ];
    return $edit;
  }

}
